[Midnightbsd-cvs] src [10145] U trunk/sys/compat/svr4/syscalls.master: sync svr4

laffer1 at midnightbsd.org laffer1 at midnightbsd.org
Wed May 30 16:35:51 EDT 2018


Revision: 10145
          http://svnweb.midnightbsd.org/src/?rev=10145
Author:   laffer1
Date:     2018-05-30 16:35:51 -0400 (Wed, 30 May 2018)
Log Message:
-----------
sync svr4

Modified Paths:
--------------
    trunk/sys/compat/svr4/Makefile
    trunk/sys/compat/svr4/imgact_svr4.c
    trunk/sys/compat/svr4/svr4.h
    trunk/sys/compat/svr4/svr4_acl.h
    trunk/sys/compat/svr4/svr4_dirent.h
    trunk/sys/compat/svr4/svr4_errno.h
    trunk/sys/compat/svr4/svr4_exec.h
    trunk/sys/compat/svr4/svr4_fcntl.c
    trunk/sys/compat/svr4/svr4_fcntl.h
    trunk/sys/compat/svr4/svr4_filio.c
    trunk/sys/compat/svr4/svr4_filio.h
    trunk/sys/compat/svr4/svr4_fuser.h
    trunk/sys/compat/svr4/svr4_hrt.h
    trunk/sys/compat/svr4/svr4_ioctl.c
    trunk/sys/compat/svr4/svr4_ioctl.h
    trunk/sys/compat/svr4/svr4_ipc.c
    trunk/sys/compat/svr4/svr4_ipc.h
    trunk/sys/compat/svr4/svr4_misc.c
    trunk/sys/compat/svr4/svr4_mman.h
    trunk/sys/compat/svr4/svr4_proto.h
    trunk/sys/compat/svr4/svr4_resource.c
    trunk/sys/compat/svr4/svr4_resource.h
    trunk/sys/compat/svr4/svr4_siginfo.h
    trunk/sys/compat/svr4/svr4_signal.c
    trunk/sys/compat/svr4/svr4_signal.h
    trunk/sys/compat/svr4/svr4_socket.c
    trunk/sys/compat/svr4/svr4_socket.h
    trunk/sys/compat/svr4/svr4_sockio.c
    trunk/sys/compat/svr4/svr4_sockio.h
    trunk/sys/compat/svr4/svr4_sockmod.h
    trunk/sys/compat/svr4/svr4_stat.c
    trunk/sys/compat/svr4/svr4_stat.h
    trunk/sys/compat/svr4/svr4_statvfs.h
    trunk/sys/compat/svr4/svr4_stream.c
    trunk/sys/compat/svr4/svr4_stropts.h
    trunk/sys/compat/svr4/svr4_syscall.h
    trunk/sys/compat/svr4/svr4_syscallnames.c
    trunk/sys/compat/svr4/svr4_sysconfig.h
    trunk/sys/compat/svr4/svr4_sysent.c
    trunk/sys/compat/svr4/svr4_systeminfo.h
    trunk/sys/compat/svr4/svr4_sysvec.c
    trunk/sys/compat/svr4/svr4_termios.c
    trunk/sys/compat/svr4/svr4_termios.h
    trunk/sys/compat/svr4/svr4_time.h
    trunk/sys/compat/svr4/svr4_timod.h
    trunk/sys/compat/svr4/svr4_types.h
    trunk/sys/compat/svr4/svr4_ucontext.h
    trunk/sys/compat/svr4/svr4_ulimit.h
    trunk/sys/compat/svr4/svr4_ustat.h
    trunk/sys/compat/svr4/svr4_util.h
    trunk/sys/compat/svr4/svr4_utsname.h
    trunk/sys/compat/svr4/svr4_wait.h
    trunk/sys/compat/svr4/syscalls.master

Property Changed:
----------------
    trunk/sys/compat/svr4/syscalls.conf
    trunk/sys/compat/svr4/syscalls.master

Modified: trunk/sys/compat/svr4/Makefile
===================================================================
--- trunk/sys/compat/svr4/Makefile	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/Makefile	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,6 +1,7 @@
+# $MidnightBSD$
 # Makefile for syscall tables
 #
-# $MidnightBSD$
+# $FreeBSD: stable/10/sys/compat/svr4/Makefile 315063 2017-03-11 08:40:59Z dchagin $
 
 all:
 	@echo "make sysent only"
@@ -9,9 +10,5 @@
 
 svr4_syscallnames.c svr4_sysent.c svr4_syscall.h svr4_proto.h: \
 		../../kern/makesyscalls.sh syscalls.master syscalls.conf
-	-mv -f svr4_syscallnames.c svr4_syscallnames.c.bak
-	-mv -f svr4_sysent.c svr4_sysent.c.bak
-	-mv -f svr4_syscall.h svr4_syscall.h.bak
-	-mv -f svr4_proto.h svr4_proto.h.bak
 	sh ../../kern/makesyscalls.sh syscalls.master syscalls.conf
 

Modified: trunk/sys/compat/svr4/imgact_svr4.c
===================================================================
--- trunk/sys/compat/svr4/imgact_svr4.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/imgact_svr4.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,6 +1,7 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
- * Copyright (c) 1994-1996 S\xF8ren Schmidt
+ * Copyright (c) 1994-1996 Søren Schmidt
  * All rights reserved.
  *
  * Based heavily on /sys/kern/imgact_aout.c which is:
@@ -31,7 +32,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/imgact_svr4.c 255426 2013-09-09 18:11:59Z jhb $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -140,8 +141,8 @@
 	 */
 	vmaddr = virtual_offset;
 	error = vm_map_find(&vmspace->vm_map, NULL, 0, &vmaddr,
-		    	    a_out->a_text + a_out->a_data + bss_size, FALSE,
-			    VM_PROT_ALL, VM_PROT_ALL, 0);
+	    a_out->a_text + a_out->a_data + bss_size, 0, VMFS_NO_SPACE,
+	    VM_PROT_ALL, VM_PROT_ALL, 0);
 	if (error)
 	    goto fail;
 
@@ -204,7 +205,7 @@
 	if (bss_size != 0) {
 	    vmaddr = virtual_offset + a_out->a_text + a_out->a_data;
 	    error = vm_map_find(&vmspace->vm_map, NULL, 0, &vmaddr, 
-				bss_size, FALSE, VM_PROT_ALL, VM_PROT_ALL, 0);
+		bss_size, 0, VMFS_NO_SPACE, VM_PROT_ALL, VM_PROT_ALL, 0);
 	    if (error)
 		goto fail;
 #ifdef DEBUG

Modified: trunk/sys/compat/svr4/svr4.h
===================================================================
--- trunk/sys/compat/svr4/svr4.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * All rights reserved.
@@ -24,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4.h 147965 2005-07-13 15:14:33Z jhb $
  */
 
 #include "opt_svr4.h"

Modified: trunk/sys/compat/svr4/svr4_acl.h
===================================================================
--- trunk/sys/compat/svr4/svr4_acl.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_acl.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1996 Christos Zoulas.  
@@ -28,7 +29,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_acl.h 139743 2005-01-05 22:34:37Z imp $
  */
 #ifndef	_SVR4_ACL_H_
 #define	_SVR4_ACL_H_

Modified: trunk/sys/compat/svr4/svr4_dirent.h
===================================================================
--- trunk/sys/compat/svr4/svr4_dirent.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_dirent.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_dirent.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_DIRENT_H_

Modified: trunk/sys/compat/svr4/svr4_errno.h
===================================================================
--- trunk/sys/compat/svr4/svr4_errno.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_errno.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_errno.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_ERRNO_H_

Modified: trunk/sys/compat/svr4/svr4_exec.h
===================================================================
--- trunk/sys/compat/svr4/svr4_exec.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_exec.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_exec.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_EXEC_H_

Modified: trunk/sys/compat/svr4/svr4_fcntl.c
===================================================================
--- trunk/sys/compat/svr4/svr4_fcntl.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_fcntl.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_fcntl.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_FCNTL_H_

Modified: trunk/sys/compat/svr4/svr4_filio.c
===================================================================
--- trunk/sys/compat/svr4/svr4_filio.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_filio.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -27,12 +28,12 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_filio.c 280258 2015-03-19 13:37:36Z rwatson $");
 
 #include <sys/param.h>
 #include <sys/proc.h>
 #include <sys/systm.h>
-#include <sys/capability.h>
+#include <sys/capsicum.h>
 #include <sys/file.h>
 #include <sys/filio.h>
 #include <sys/lock.h>
@@ -104,6 +105,7 @@
      struct svr4_sys_read_args *uap;
 {
      struct read_args ra;
+     cap_rights_t rights;
      struct file *fp;
      struct socket *so = NULL;
      int so_state;
@@ -114,7 +116,7 @@
      ra.buf = uap->buf;
      ra.nbyte = uap->nbyte;
 
-     if (fget(td, uap->fd, CAP_READ, &fp) != 0) {
+     if (fget(td, uap->fd, cap_rights_init(&rights, CAP_READ), &fp) != 0) {
        DPRINTF(("Something fishy with the user-supplied file descriptor...\n"));
        return EBADF;
      }
@@ -197,9 +199,9 @@
 	u_long cmd;
 	caddr_t data;
 {
-	int error;
-	int num;
 	struct filedesc *fdp = td->td_proc->p_fd;
+	struct filedescent *fde;
+	int error, num;
 
 	*retval = 0;
 
@@ -206,13 +208,15 @@
 	switch (cmd) {
 	case SVR4_FIOCLEX:
 		FILEDESC_XLOCK(fdp);
-		fdp->fd_ofileflags[fd] |= UF_EXCLOSE;
+		fde = &fdp->fd_ofiles[fd];
+		fde->fde_flags |= UF_EXCLOSE;
 		FILEDESC_XUNLOCK(fdp);
 		return 0;
 
 	case SVR4_FIONCLEX:
 		FILEDESC_XLOCK(fdp);
-		fdp->fd_ofileflags[fd] &= ~UF_EXCLOSE;
+		fde = &fdp->fd_ofiles[fd];
+		fde->fde_flags &= ~UF_EXCLOSE;
 		FILEDESC_XUNLOCK(fdp);
 		return 0;
 

Modified: trunk/sys/compat/svr4/svr4_filio.h
===================================================================
--- trunk/sys/compat/svr4/svr4_filio.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_filio.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_filio.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_FILIO_H_

Modified: trunk/sys/compat/svr4/svr4_fuser.h
===================================================================
--- trunk/sys/compat/svr4/svr4_fuser.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_fuser.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,5 +1,6 @@
+/* $MidnightBSD$ */
 /*
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_fuser.h 263687 2014-03-24 13:48:04Z emaste $
  *	Derived from:
  *	$NetBSD: svr4_fuser.h,v 1.4 1998/09/04 19:54:38 christos Exp $	 */
 
@@ -20,13 +21,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by the NetBSD
- *        Foundation, Inc. and its contributors.
- * 4. Neither the name of The NetBSD Foundation nor the names of its
- *    contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED

Modified: trunk/sys/compat/svr4/svr4_hrt.h
===================================================================
--- trunk/sys/compat/svr4/svr4_hrt.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_hrt.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_hrt.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_HRT_H_

Modified: trunk/sys/compat/svr4/svr4_ioctl.c
===================================================================
--- trunk/sys/compat/svr4/svr4_ioctl.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_ioctl.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -27,11 +28,11 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_ioctl.c 280258 2015-03-19 13:37:36Z rwatson $");
 
 #include <sys/param.h>
 #include <sys/proc.h>
-#include <sys/capability.h>
+#include <sys/capsicum.h>
 #include <sys/file.h>
 #include <sys/filedesc.h>
 #include <sys/fcntl.h>
@@ -84,6 +85,7 @@
 	struct svr4_sys_ioctl_args *uap;
 {
 	int             *retval;
+	cap_rights_t	 rights;
 	struct file	*fp;
 	u_long		 cmd;
 	int (*fun)(struct file *, struct thread *, register_t *,
@@ -103,7 +105,8 @@
 	retval = td->td_retval;
 	cmd = uap->com;
 
-	if ((error = fget(td, uap->fd, CAP_IOCTL, &fp)) != 0)
+	error = fget(td, uap->fd, cap_rights_init(&rights, CAP_IOCTL), &fp);
+	if (error != 0)
 		return (error);
 
 	if ((fp->f_flag & (FREAD | FWRITE)) == 0) {

Modified: trunk/sys/compat/svr4/svr4_ioctl.h
===================================================================
--- trunk/sys/compat/svr4/svr4_ioctl.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_ioctl.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_ioctl.h 191919 2009-05-08 20:06:37Z ed $
  */
 
 #ifndef	_SVR4_IOCTL_H_

Modified: trunk/sys/compat/svr4/svr4_ipc.c
===================================================================
--- trunk/sys/compat/svr4/svr4_ipc.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_ipc.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1995 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -13,13 +14,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by the NetBSD
- *        Foundation, Inc. and its contributors.
- * 4. Neither the name of The NetBSD Foundation nor the names of its
- *    contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -71,7 +65,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_ipc.c 299215 2016-05-07 08:30:21Z dchagin $");
 
 #include "opt_sysvipc.h"
 
@@ -93,14 +87,10 @@
 #include <compat/svr4/svr4_util.h>
 #include <compat/svr4/svr4_ipc.h>
 
-#if defined(SYSVMSG) || defined(SYSVSHM) || defined(SYSVSEM)
 static void svr4_to_bsd_ipc_perm(const struct svr4_ipc_perm *,
 				      struct ipc_perm *);
 static void bsd_to_svr4_ipc_perm(const struct ipc_perm *,
 				      struct svr4_ipc_perm *);
-#endif
-
-#ifdef SYSVSEM
 static void bsd_to_svr4_semid_ds(const struct semid_ds *,
 				      struct svr4_semid_ds *);
 static void svr4_to_bsd_semid_ds(const struct svr4_semid_ds *,
@@ -108,9 +98,6 @@
 static int svr4_semop(struct thread *, void *);
 static int svr4_semget(struct thread *, void *);
 static int svr4_semctl(struct thread *, void *);
-#endif
-
-#ifdef SYSVMSG
 static void bsd_to_svr4_msqid_ds(const struct msqid_ds *,
 				      struct svr4_msqid_ds *);
 static void svr4_to_bsd_msqid_ds(const struct svr4_msqid_ds *,
@@ -119,9 +106,6 @@
 static int svr4_msgrcv(struct thread *, void *);
 static int svr4_msgget(struct thread *, void *);
 static int svr4_msgctl(struct thread *, void *);
-#endif
-
-#ifdef SYSVSHM
 static void bsd_to_svr4_shmid_ds(const struct shmid_ds *,
 				      struct svr4_shmid_ds *);
 static void svr4_to_bsd_shmid_ds(const struct svr4_shmid_ds *,
@@ -130,10 +114,7 @@
 static int svr4_shmdt(struct thread *, void *);
 static int svr4_shmget(struct thread *, void *);
 static int svr4_shmctl(struct thread *, void *);
-#endif
 
-#if defined(SYSVMSG) || defined(SYSVSHM) || defined(SYSVSEM)
-
 static void
 svr4_to_bsd_ipc_perm(spp, bpp)
 	const struct svr4_ipc_perm *spp;
@@ -161,9 +142,7 @@
 	spp->mode = bpp->mode;
 	spp->seq = bpp->seq;
 }
-#endif
 
-#ifdef SYSVSEM
 static void
 bsd_to_svr4_semid_ds(bds, sds)
 	const struct semid_ds *bds;
@@ -338,10 +317,7 @@
 	}
 }
 
-MODULE_DEPEND(svr4elf, sysvsem, 1, 1, 1);
-#endif
 
-#ifdef SYSVMSG
 static void
 bsd_to_svr4_msqid_ds(bds, sds)
 	const struct msqid_ds *bds;
@@ -428,7 +404,7 @@
 
 	return sys_msgrcv(td, &ap);
 }
-	
+
 struct svr4_sys_msgget_args {
 	int what;
 	svr4_key_t key;
@@ -511,11 +487,7 @@
 	}
 }
 
-MODULE_DEPEND(svr4elf, sysvmsg, 1, 1, 1);
-#endif
 
-#ifdef SYSVSHM
-
 static void
 bsd_to_svr4_shmid_ds(bds, sds)
 	const struct shmid_ds *bds;
@@ -664,7 +636,7 @@
 	default:
 		return (EINVAL);
 	}
-		
+
 	error = kern_shmctl(td, uap->shmid, cmd, &bs, &bufsize);
 	if (error)
 		return (error);
@@ -704,4 +676,5 @@
 }
 
 MODULE_DEPEND(svr4elf, sysvshm, 1, 1, 1);
-#endif /* SYSVSHM */
+MODULE_DEPEND(svr4elf, sysvmsg, 1, 1, 1);
+MODULE_DEPEND(svr4elf, sysvsem, 1, 1, 1);

Modified: trunk/sys/compat/svr4/svr4_ipc.h
===================================================================
--- trunk/sys/compat/svr4/svr4_ipc.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_ipc.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1995 Christos Zoulas.  All rights reserved.
@@ -27,7 +28,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_ipc.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef _SVR4_IPC_H_

Modified: trunk/sys/compat/svr4/svr4_misc.c
===================================================================
--- trunk/sys/compat/svr4/svr4_misc.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_misc.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -33,11 +34,11 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_misc.c 331749 2018-03-29 22:31:14Z emaste $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
-#include <sys/capability.h>
+#include <sys/capsicum.h>
 #include <sys/dirent.h>
 #include <sys/fcntl.h>
 #include <sys/filedesc.h>
@@ -167,15 +168,22 @@
 	struct svr4_sys_execv_args *uap;
 {
 	struct image_args eargs;
+	struct vmspace *oldvmspace;
 	char *path;
 	int error;
 
 	CHECKALTEXIST(td, uap->path, &path);
 
+	error = pre_execve(td, &oldvmspace);
+	if (error != 0) {
+		free(path, M_TEMP);
+		return (error);
+	}
 	error = exec_copyin_args(&eargs, path, UIO_SYSSPACE, uap->argp, NULL);
 	free(path, M_TEMP);
 	if (error == 0)
 		error = kern_execve(td, &eargs, NULL);
+	post_execve(td, error, oldvmspace);
 	return (error);
 }
 
@@ -185,16 +193,23 @@
 	struct svr4_sys_execve_args *uap;
 {
 	struct image_args eargs;
+	struct vmspace *oldvmspace;
 	char *path;
 	int error;
 
 	CHECKALTEXIST(td, uap->path, &path);
 
+	error = pre_execve(td, &oldvmspace);
+	if (error != 0) {
+		free(path, M_TEMP);
+		return (error);
+	}
 	error = exec_copyin_args(&eargs, path, UIO_SYSSPACE, uap->argp,
 	    uap->envp);
 	free(path, M_TEMP);
 	if (error == 0)
 		error = kern_execve(td, &eargs, NULL);
+	post_execve(td, error, oldvmspace);
 	return (error);
 }
 
@@ -236,21 +251,23 @@
 	int len, reclen;		/* BSD-format */
 	caddr_t outp;			/* SVR4-format */
 	int resid, svr4reclen=0;	/* SVR4-format */
+	cap_rights_t rights;
 	struct file *fp;
 	struct uio auio;
 	struct iovec aiov;
 	off_t off;
 	struct svr4_dirent64 svr4_dirent;
-	int buflen, error, eofflag, nbytes, justone, vfslocked;
+	int buflen, error, eofflag, nbytes, justone;
 	u_long *cookies = NULL, *cookiep;
 	int ncookies;
 
+	memset(&svr4_dirent, 0, sizeof(svr4_dirent));
 	DPRINTF(("svr4_sys_getdents64(%d, *, %d)\n",
 		uap->fd, uap->nbytes));
-	if ((error = getvnode(td->td_proc->p_fd, uap->fd,
-	    CAP_READ | CAP_SEEK, &fp)) != 0) {
+	error = getvnode(td->td_proc->p_fd, uap->fd,
+	    cap_rights_init(&rights, CAP_READ), &fp);
+	if (error != 0)
 		return (error);
-	}
 
 	if ((fp->f_flag & FREAD) == 0) {
 		fdrop(fp, td);
@@ -258,9 +275,7 @@
 	}
 
 	vp = fp->f_vnode;
-	vfslocked = VFS_LOCK_GIANT(vp->v_mount);
 	if (vp->v_type != VDIR) {
-		VFS_UNLOCK_GIANT(vfslocked);
 		fdrop(fp, td);
 		return (EINVAL);
 	}
@@ -397,7 +412,6 @@
 	td->td_retval[0] = nbytes - resid;
 out:
 	VOP_UNLOCK(vp, 0);
-	VFS_UNLOCK_GIANT(vfslocked);
 	fdrop(fp, td);
 	if (cookies)
 		free(cookies, M_TEMP);
@@ -417,12 +431,13 @@
 	int len, reclen;	/* BSD-format */
 	caddr_t outp;		/* SVR4-format */
 	int resid, svr4_reclen;	/* SVR4-format */
+	cap_rights_t rights;
 	struct file *fp;
 	struct uio auio;
 	struct iovec aiov;
 	struct svr4_dirent idb;
 	off_t off;		/* true file offset */
-	int buflen, error, eofflag, vfslocked;
+	int buflen, error, eofflag;
 	u_long *cookiebuf = NULL, *cookie;
 	int ncookies = 0, *retval = td->td_retval;
 
@@ -429,8 +444,9 @@
 	if (uap->nbytes < 0)
 		return (EINVAL);
 
-	if ((error = getvnode(td->td_proc->p_fd, uap->fd,
-	    CAP_READ | CAP_SEEK, &fp)) != 0)
+	error = getvnode(td->td_proc->p_fd, uap->fd,
+	    cap_rights_init(&rights, CAP_READ), &fp);
+	if (error != 0)
 		return (error);
 
 	if ((fp->f_flag & FREAD) == 0) {
@@ -439,9 +455,7 @@
 	}
 
 	vp = fp->f_vnode;
-	vfslocked = VFS_LOCK_GIANT(vp->v_mount);
 	if (vp->v_type != VDIR) {
-		VFS_UNLOCK_GIANT(vfslocked);
 		fdrop(fp, td);
 		return (EINVAL);
 	}
@@ -534,7 +548,6 @@
 	*retval = uap->nbytes - resid;
 out:
 	VOP_UNLOCK(vp, 0);
-	VFS_UNLOCK_GIANT(vfslocked);
 	fdrop(fp, td);
 	if (cookiebuf)
 		free(cookiebuf, M_TEMP);
@@ -614,7 +627,7 @@
 	struct filedesc	*fdp = td->td_proc->p_fd;
 	struct vnode	*vp;
 	struct file	*fp;
-	int		 error, vfslocked;
+	int		 error;
 
 	if ((error = priv_check(td, PRIV_VFS_FCHROOT)) != 0)
 		return error;
@@ -624,7 +637,6 @@
 	vp = fp->f_vnode;
 	VREF(vp);
 	fdrop(fp, td);
-	vfslocked = VFS_LOCK_GIANT(vp->v_mount);
 	vn_lock(vp, LK_EXCLUSIVE | LK_RETRY);
 	error = change_dir(vp, td);
 	if (error)
@@ -637,11 +649,9 @@
 	VOP_UNLOCK(vp, 0);
 	error = change_root(vp, td);
 	vrele(vp);
-	VFS_UNLOCK_GIANT(vfslocked);
 	return (error);
 fail:
 	vput(vp);
-	VFS_UNLOCK_GIANT(vfslocked);
 	return (error);
 }
 
@@ -867,9 +877,9 @@
 
 	p = td->td_proc;
 	PROC_LOCK(p);
-	PROC_SLOCK(p);
+	PROC_STATLOCK(p);
 	calcru(p, &utime, &stime);
-	PROC_SUNLOCK(p);
+	PROC_STATUNLOCK(p);
 	calccru(p, &cutime, &cstime);
 	PROC_UNLOCK(p);
 
@@ -1280,9 +1290,9 @@
 			pid = p->p_pid;
 			status = p->p_xstat;
 			ru = p->p_ru;
-			PROC_SLOCK(p);
+			PROC_STATLOCK(p);
 			calcru(p, &ru.ru_utime, &ru.ru_stime);
-			PROC_SUNLOCK(p);
+			PROC_STATUNLOCK(p);
 			PROC_UNLOCK(p);
 			sx_sunlock(&proctree_lock);
 
@@ -1307,9 +1317,9 @@
 			pid = p->p_pid;
 			status = W_STOPCODE(p->p_xstat);
 			ru = p->p_ru;
-			PROC_SLOCK(p);
+			PROC_STATLOCK(p);
 			calcru(p, &ru.ru_utime, &ru.ru_stime);
-			PROC_SUNLOCK(p);
+			PROC_STATUNLOCK(p);
 			PROC_UNLOCK(p);
 
 		        if (((uap->options & SVR4_WNOWAIT)) == 0) {
@@ -1331,9 +1341,9 @@
 			pid = p->p_pid;
 			ru = p->p_ru;
 			status = SIGCONT;
-			PROC_SLOCK(p);
+			PROC_STATLOCK(p);
 			calcru(p, &ru.ru_utime, &ru.ru_stime);
-			PROC_SUNLOCK(p);
+			PROC_STATUNLOCK(p);
 			PROC_UNLOCK(p);
 
 		        if (((uap->options & SVR4_WNOWAIT)) == 0) {
@@ -1652,13 +1662,12 @@
 	int error, *retval = td->td_retval;
 	unsigned int ncopy;
 
-	NDINIT(&nd, LOOKUP, NOFOLLOW | SAVENAME | MPSAFE, UIO_USERSPACE,
+	NDINIT(&nd, LOOKUP, NOFOLLOW | SAVENAME, UIO_USERSPACE,
 	    uap->path, td);
 
 	if ((error = namei(&nd)) != 0)
 		return (error);
 	NDFREE(&nd, NDF_NO_FREE_PNBUF);
-	VFS_UNLOCK_GIANT(NDHASGIANT(&nd));
 
 	ncopy = min(uap->bufsiz, strlen(nd.ni_cnd.cn_pnbuf) + 1);
 	if ((error = copyout(nd.ni_cnd.cn_pnbuf, uap->buf, ncopy)) != 0)

Modified: trunk/sys/compat/svr4/svr4_mman.h
===================================================================
--- trunk/sys/compat/svr4/svr4_mman.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_mman.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1997 Todd Vierling
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_mman.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef _SVR4_MMAN_H_

Modified: trunk/sys/compat/svr4/svr4_proto.h
===================================================================
--- trunk/sys/compat/svr4/svr4_proto.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_proto.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,9 +1,9 @@
+/* $MidnightBSD$ */
 /*
  * System call prototypes.
  *
  * DO NOT EDIT-- this file is automatically generated.
- * $MidnightBSD$
- * created from FreeBSD: head/sys/compat/svr4/syscalls.master 203660 2010-02-08 10:02:01Z ed 
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_proto.h 318164 2017-05-10 23:09:17Z jhb $
  */
 
 #ifndef _SVR4_SYSPROTO_H_
@@ -12,8 +12,10 @@
 #include <sys/signal.h>
 #include <sys/acl.h>
 #include <sys/cpuset.h>
+#include <sys/_ffcounter.h>
 #include <sys/_semaphore.h>
 #include <sys/ucontext.h>
+#include <sys/wait.h>
 
 #include <bsm/audit_kevents.h>
 
@@ -79,7 +81,7 @@
 };
 struct svr4_sys_access_args {
 	char path_l_[PADL_(char *)]; char * path; char path_r_[PADR_(char *)];
-	char flags_l_[PADL_(int)]; int flags; char flags_r_[PADR_(int)];
+	char amode_l_[PADL_(int)]; int amode; char amode_r_[PADR_(int)];
 };
 struct svr4_sys_nice_args {
 	char prio_l_[PADL_(int)]; int prio; char prio_r_[PADR_(int)];

Modified: trunk/sys/compat/svr4/svr4_resource.c
===================================================================
--- trunk/sys/compat/svr4/svr4_resource.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_resource.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -13,13 +14,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by the NetBSD
- *        Foundation, Inc. and its contributors.
- * 4. Neither the name of The NetBSD Foundation nor the names of its
- *    contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -66,7 +60,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_resource.c 263687 2014-03-24 13:48:04Z emaste $");
 
 #include <sys/param.h>
 #include <sys/systm.h>

Modified: trunk/sys/compat/svr4/svr4_resource.h
===================================================================
--- trunk/sys/compat/svr4/svr4_resource.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_resource.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*	Derived from:
  *	$NetBSD: svr4_resource.h,v 1.1 1998/11/28 21:53:02 christos Exp $	*/
 
@@ -18,13 +19,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by the NetBSD
- *        Foundation, Inc. and its contributors.
- * 4. Neither the name of The NetBSD Foundation nor the names of its
- *    contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -38,7 +32,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_resource.h 263687 2014-03-24 13:48:04Z emaste $
  */
 
 /*-

Modified: trunk/sys/compat/svr4/svr4_siginfo.h
===================================================================
--- trunk/sys/compat/svr4/svr4_siginfo.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_siginfo.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_siginfo.h 151463 2005-10-19 09:33:15Z davidxu $
  */
 
 #ifndef	_SVR4_SIGINFO_H_

Modified: trunk/sys/compat/svr4/svr4_signal.c
===================================================================
--- trunk/sys/compat/svr4/svr4_signal.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_signal.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -27,7 +28,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_signal.c 225617 2011-09-16 13:58:51Z kmacy $");
 
 #include <sys/param.h>
 #include <sys/systm.h>

Modified: trunk/sys/compat/svr4/svr4_signal.h
===================================================================
--- trunk/sys/compat/svr4/svr4_signal.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_signal.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_signal.h 151316 2005-10-14 12:43:47Z davidxu $
  */
 
 #ifndef	_SVR4_SIGNAL_H_

Modified: trunk/sys/compat/svr4/svr4_socket.c
===================================================================
--- trunk/sys/compat/svr4/svr4_socket.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_socket.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1996 Christos Zoulas. 
@@ -41,7 +42,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_socket.c 299215 2016-05-07 08:30:21Z dchagin $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -66,6 +67,7 @@
 #include <compat/svr4/svr4_signal.h>
 #include <compat/svr4/svr4_sockmod.h>
 #include <compat/svr4/svr4_proto.h>
+#include <compat/svr4/svr4_stropts.h>
 
 struct svr4_sockcache_entry {
 	struct proc *p;		/* Process for the socket		*/
@@ -168,6 +170,19 @@
 	mtx_unlock(&svr4_sockcache_lock);
 }
 
+struct svr4_strm *
+svr4_stream_get(fp)
+	struct file *fp;
+{
+	struct socket *so;
+
+	if (fp == NULL || fp->f_type != DTYPE_SOCKET)
+		return NULL;
+
+	so = fp->f_data;
+	return so->so_emuldata;
+}
+
 void
 svr4_purge_sockcache(arg, p)
 	void *arg;

Modified: trunk/sys/compat/svr4/svr4_socket.h
===================================================================
--- trunk/sys/compat/svr4/svr4_socket.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_socket.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1996 Christos Zoulas. 
@@ -28,7 +29,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_socket.h 160558 2006-07-21 20:40:13Z jhb $
  */
 
 #ifndef _SVR4_SOCKET_H_

Modified: trunk/sys/compat/svr4/svr4_sockio.c
===================================================================
--- trunk/sys/compat/svr4/svr4_sockio.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_sockio.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1995 Christos Zoulas
@@ -27,7 +28,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_sockio.c 196019 2009-08-01 19:26:27Z rwatson $");
 
 #include <sys/param.h>
 #include <sys/proc.h>

Modified: trunk/sys/compat/svr4/svr4_sockio.h
===================================================================
--- trunk/sys/compat/svr4/svr4_sockio.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_sockio.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1995 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_sockio.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_SOCKIO_H_

Modified: trunk/sys/compat/svr4/svr4_sockmod.h
===================================================================
--- trunk/sys/compat/svr4/svr4_sockmod.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_sockmod.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_sockmod.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_SOCKMOD_H_

Modified: trunk/sys/compat/svr4/svr4_stat.c
===================================================================
--- trunk/sys/compat/svr4/svr4_stat.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_stat.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -27,7 +28,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_stat.c 225617 2011-09-16 13:58:51Z kmacy $");
 
 #include <sys/param.h>
 #include <sys/systm.h>

Modified: trunk/sys/compat/svr4/svr4_stat.h
===================================================================
--- trunk/sys/compat/svr4/svr4_stat.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_stat.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_stat.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_STAT_H_

Modified: trunk/sys/compat/svr4/svr4_statvfs.h
===================================================================
--- trunk/sys/compat/svr4/svr4_statvfs.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_statvfs.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_statvfs.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_STATVFS_H_

Modified: trunk/sys/compat/svr4/svr4_stream.c
===================================================================
--- trunk/sys/compat/svr4/svr4_stream.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_stream.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton.  All rights reserved.
  * Copyright (c) 1994, 1996 Christos Zoulas.  All rights reserved.
@@ -36,7 +37,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_stream.c 321020 2017-07-15 17:25:40Z dchagin $");
 
 #include "opt_compat.h"
 #include "opt_ktrace.h"
@@ -43,7 +44,7 @@
 
 #include <sys/param.h>
 #include <sys/systm.h>
-#include <sys/capability.h>
+#include <sys/capsicum.h>
 #include <sys/fcntl.h>
 #include <sys/filedesc.h>
 #include <sys/filio.h>
@@ -1446,10 +1447,12 @@
 	struct thread *td;
 	struct svr4_sys_putmsg_args *uap;
 {
-	struct file     *fp;
+	cap_rights_t rights;
+	struct file *fp;
 	int error;
 
-	if ((error = fget(td, uap->fd, CAP_WRITE, &fp)) != 0) {
+	error = fget(td, uap->fd, cap_rights_init(&rights, CAP_SEND), &fp);
+	if (error != 0) {
 #ifdef DEBUG_SVR4
 	        uprintf("putmsg: bad fp\n");
 #endif
@@ -1618,10 +1621,12 @@
 	struct thread *td;
 	struct svr4_sys_getmsg_args *uap;
 {
-	struct file     *fp;
+	cap_rights_t rights;
+	struct file *fp;
 	int error;
 
-	if ((error = fget(td, uap->fd, CAP_READ, &fp)) != 0) {
+	error = fget(td, uap->fd, cap_rights_init(&rights, CAP_RECV), &fp);
+	if (error != 0) {
 #ifdef DEBUG_SVR4
 	        uprintf("getmsg: bad fp\n");
 #endif
@@ -1824,7 +1829,7 @@
 			break;
 
 		default:
-			fdclose(td->td_proc->p_fd, afp, st->s_afd, td);
+			fdclose(td, afp, st->s_afd);
 			fdrop(afp, td);
 			st->s_afd = -1;
 			mtx_unlock(&Giant);
@@ -1962,7 +1967,7 @@
 
 	if (error) {
 		if (afp) {
-			fdclose(td->td_proc->p_fd, afp, st->s_afd, td);
+			fdclose(td, afp, st->s_afd);
 			fdrop(afp, td);
 			st->s_afd = -1;
 		}

Modified: trunk/sys/compat/svr4/svr4_stropts.h
===================================================================
--- trunk/sys/compat/svr4/svr4_stropts.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_stropts.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_stropts.h 160794 2006-07-28 16:56:17Z jhb $
  */
 
 #ifndef	_SVR4_STROPTS_H_

Modified: trunk/sys/compat/svr4/svr4_syscall.h
===================================================================
--- trunk/sys/compat/svr4/svr4_syscall.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_syscall.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,9 +1,9 @@
+/* $MidnightBSD$ */
 /*
  * System call numbers.
  *
  * DO NOT EDIT-- this file is automatically generated.
- * $MidnightBSD$
- * created from FreeBSD: head/sys/compat/svr4/syscalls.master 203660 2010-02-08 10:02:01Z ed 
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_syscall.h 318164 2017-05-10 23:09:17Z jhb $
  */
 
 #define	SVR4_SYS_exit	1

Modified: trunk/sys/compat/svr4/svr4_syscallnames.c
===================================================================
--- trunk/sys/compat/svr4/svr4_syscallnames.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_syscallnames.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,9 +1,9 @@
+/* $MidnightBSD$ */
 /*
  * System call names.
  *
  * DO NOT EDIT-- this file is automatically generated.
- * $MidnightBSD$
- * created from FreeBSD: head/sys/compat/svr4/syscalls.master 203660 2010-02-08 10:02:01Z ed 
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_syscallnames.c 318164 2017-05-10 23:09:17Z jhb $
  */
 
 const char *svr4_syscallnames[] = {

Modified: trunk/sys/compat/svr4/svr4_sysconfig.h
===================================================================
--- trunk/sys/compat/svr4/svr4_sysconfig.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_sysconfig.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1995 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_sysconfig.h 193012 2009-05-29 05:37:27Z delphij $
  */
 
 #ifndef	_SVR4_SYSCONFIG_H_

Modified: trunk/sys/compat/svr4/svr4_sysent.c
===================================================================
--- trunk/sys/compat/svr4/svr4_sysent.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_sysent.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,9 +1,9 @@
+/* $MidnightBSD$ */
 /*
  * System call switch table.
  *
  * DO NOT EDIT-- this file is automatically generated.
- * $MidnightBSD$
- * created from FreeBSD: head/sys/compat/svr4/syscalls.master 203660 2010-02-08 10:02:01Z ed 
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_sysent.c 318164 2017-05-10 23:09:17Z jhb $
  */
 
 #include <sys/types.h>

Modified: trunk/sys/compat/svr4/svr4_systeminfo.h
===================================================================
--- trunk/sys/compat/svr4/svr4_systeminfo.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_systeminfo.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_systeminfo.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_SYSTEMINFO_H_

Modified: trunk/sys/compat/svr4/svr4_sysvec.c
===================================================================
--- trunk/sys/compat/svr4/svr4_sysvec.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_sysvec.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * All rights reserved.
@@ -29,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_sysvec.c 299215 2016-05-07 08:30:21Z dchagin $");
 
 /* XXX we use functions that might not exist. */
 #include "opt_compat.h"
@@ -196,6 +197,8 @@
 	.sv_fetch_syscall_args = cpu_fetch_syscall_args,
 	.sv_syscallnames = NULL,
 	.sv_schedtail	= NULL,
+	.sv_thread_detach = NULL,
+	.sv_trap	= NULL,
 };
 
 const char      svr4_emul_path[] = "/compat/svr4";
@@ -311,4 +314,4 @@
 	0
 };
 DECLARE_MODULE_TIED(svr4elf, svr4_elf_mod, SI_SUB_EXEC, SI_ORDER_ANY);
-MODULE_DEPEND(svr4elf, streams, 1, 1, 1);
+MODULE_VERSION(svr4elf, 1);

Modified: trunk/sys/compat/svr4/svr4_termios.c
===================================================================
--- trunk/sys/compat/svr4/svr4_termios.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_termios.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -27,7 +28,7 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_termios.c 199882 2009-11-28 16:30:06Z ed $");
 
 #include <sys/param.h>
 #include <sys/proc.h>

Modified: trunk/sys/compat/svr4/svr4_termios.h
===================================================================
--- trunk/sys/compat/svr4/svr4_termios.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_termios.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_termios.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_TERMIOS_H_

Modified: trunk/sys/compat/svr4/svr4_time.h
===================================================================
--- trunk/sys/compat/svr4/svr4_time.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_time.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_time.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_TIME_H_

Modified: trunk/sys/compat/svr4/svr4_timod.h
===================================================================
--- trunk/sys/compat/svr4/svr4_timod.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_timod.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_timod.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_TIMOD_H_

Modified: trunk/sys/compat/svr4/svr4_types.h
===================================================================
--- trunk/sys/compat/svr4/svr4_types.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_types.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_types.h 187830 2009-01-28 17:57:16Z ed $
  */
 
 #ifndef	_SVR4_TYPES_H_

Modified: trunk/sys/compat/svr4/svr4_ucontext.h
===================================================================
--- trunk/sys/compat/svr4/svr4_ucontext.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_ucontext.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_ucontext.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_UCONTEXT_H_

Modified: trunk/sys/compat/svr4/svr4_ulimit.h
===================================================================
--- trunk/sys/compat/svr4/svr4_ulimit.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_ulimit.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_ulimit.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_ULIMIT_H_

Modified: trunk/sys/compat/svr4/svr4_ustat.h
===================================================================
--- trunk/sys/compat/svr4/svr4_ustat.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_ustat.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_ustat.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_USTAT_H_

Modified: trunk/sys/compat/svr4/svr4_util.h
===================================================================
--- trunk/sys/compat/svr4/svr4_util.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_util.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_util.h 160249 2006-07-10 21:38:17Z jhb $
  */
 
 #ifndef	_SVR4_UTIL_H_

Modified: trunk/sys/compat/svr4/svr4_utsname.h
===================================================================
--- trunk/sys/compat/svr4/svr4_utsname.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_utsname.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_utsname.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_UTSNAME_H_

Modified: trunk/sys/compat/svr4/svr4_wait.h
===================================================================
--- trunk/sys/compat/svr4/svr4_wait.h	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_wait.h	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994 Christos Zoulas
@@ -25,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $MidnightBSD$
+ * $FreeBSD: stable/10/sys/compat/svr4/svr4_wait.h 139743 2005-01-05 22:34:37Z imp $
  */
 
 #ifndef	_SVR4_WAIT_H_

Index: trunk/sys/compat/svr4/syscalls.conf
===================================================================
--- trunk/sys/compat/svr4/syscalls.conf	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/syscalls.conf	2018-05-30 20:35:51 UTC (rev 10145)

Property changes on: trunk/sys/compat/svr4/syscalls.conf
___________________________________________________________________
Added: svn:keywords
## -0,0 +1 ##
+MidnightBSD=%H
\ No newline at end of property
Modified: trunk/sys/compat/svr4/syscalls.master
===================================================================
--- trunk/sys/compat/svr4/syscalls.master	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/syscalls.master	2018-05-30 20:35:51 UTC (rev 10145)
@@ -77,7 +77,7 @@
 31	AUE_NULL	UNIMPL	stty
 32	AUE_NULL	UNIMPL	gtty
 33	AUE_NULL	STD	{ int svr4_sys_access(char *path, \
-				    int flags); }
+				    int amode); }
 34	AUE_NULL	STD	{ int svr4_sys_nice(int prio); }
 35	AUE_NULL	UNIMPL	statfs
 36	AUE_NULL	NOPROTO	{ int sync(void); }


Property changes on: trunk/sys/compat/svr4/syscalls.master
___________________________________________________________________
Added: svn:keywords
## -0,0 +1 ##
+MidnightBSD=%H
\ No newline at end of property


More information about the Midnightbsd-cvs mailing list
--- trunk/sys/compat/svr4/svr4_fcntl.c	2018-05-28 19:14:56 UTC (rev 10144)
+++ trunk/sys/compat/svr4/svr4_fcntl.c	2018-05-30 20:35:51 UTC (rev 10145)
@@ -1,3 +1,4 @@
+/* $MidnightBSD$ */
 /*-
  * Copyright (c) 1998 Mark Newton
  * Copyright (c) 1994, 1997 Christos Zoulas.  
@@ -30,10 +31,10 @@
  */
 
 #include <sys/cdefs.h>
-__MBSDID("$MidnightBSD$");
+__FBSDID("$FreeBSD: stable/10/sys/compat/svr4/svr4_fcntl.c 280258 2015-03-19 13:37:36Z rwatson $");
 
 #include <sys/param.h>
-#include <sys/capability.h>
+#include <sys/capsicum.h>
 #include <sys/systm.h>
 #include <sys/file.h>
 #include <sys/filedesc.h>
@@ -259,6 +260,7 @@
 	struct vnode *vp;
 	struct mount *mp;
 	struct vattr vattr;
+	cap_rights_t rights;
 	int error, *retval;
 
 	retval = td->td_retval;
@@ -265,14 +267,15 @@
 	/*
 	 * If we ever want to support Capsicum on SVR4 processes (unlikely)
 	 * or FreeBSD grows a native frevoke() (more likely), we will need a
-	 * CAP_REVOKE here.
+	 * CAP_FREVOKE here.
 	 *
 	 * In the meantime, use CAP_MASK_VALID: if a SVR4 process wants to
 	 * do an frevoke(), it needs to do it on either a regular file
 	 * descriptor or a fully-privileged capability (which is effectively
 	 * the same as a non-capability-restricted file descriptor).
 	 */
-	if ((error = fgetvp(td, fd, CAP_MASK_VALID, &vp)) != 0)
+	CAP_ALL(&rights);
+	if ((error = fgetvp(td, fd, &rights, &vp)) != 0)
 		return (error);
 
 	if (vp->v_type != VCHR && vp->v_type != VBLK) {
@@ -318,6 +321,7 @@
 	struct vattr vattr;
 	int error, *retval;
 	struct ftruncate_args ft;
+	cap_rights_t rights;
 
 	retval = td->td_retval;
 
@@ -324,7 +328,8 @@
 	/*
 	 * We only support truncating the file.
 	 */
-	if ((error = fget(td, fd, CAP_FTRUNCATE, &fp)) != 0)
+	error = fget(td, fd, cap_rights_init(&rights, CAP_FTRUNCATE), &fp);
+	if (error != 0)
 		return (error);
 
 	vp = fp->f_vnode;
@@ -401,9 +406,11 @@
 	if (!(bsd_flags & O_NOCTTY) && SESS_LEADER(p) &&
 	    !(p->p_flag & P_CONTROLT)) {
 #if defined(NOTYET)
-		struct file	*fp;
+		cap_rights_t rights;
+		struct file *fp;
 
-		error = fget(td, retval, CAP_IOCTL, &fp);
+		error = fget(td, retval,
+		    cap_rights_init(&rights, CAP_IOCTL), &fp);
 		PROC_UNLOCK(p);
 		/*
 		 * we may have lost a race the above open() and
@@ -488,7 +495,7 @@
 	int error;
 
 	CHECKALTEXIST(td, uap->path, &newpath);
-	error = kern_access(td, newpath, UIO_SYSSPACE, uap->flags);
+	error = kern_access(td, newpath, UIO_SYSSPACE, uap->amode);
 	free(newpath, M_TEMP);
 	return (error);
 }
@@ -265,14 +267,15 @@
 	 *
-	 * In the meantime, use CAP_MASK_VALID: if a SVR4 process wants to
+	 * In the meantime, use CAP_ALL(): if a SVR4 process wants to
 	 * do an frevoke(), it needs to do it on either a regular file
 	 * descriptor or a fully-privileged capability (which is effectively

Modified: trunk/sys/compat/svr4/svr4_fcntl.h
===================================================================